pub struct Value { /* private fields */ }Expand description
The value of a TextInput.
Implementations
Sourceimpl Value
impl Value
Sourcepub fn previous_start_of_word(&self, index: usize) -> usize
pub fn previous_start_of_word(&self, index: usize) -> usize
Returns the position of the previous start of a word from the given
grapheme index.
Sourcepub fn next_end_of_word(&self, index: usize) -> usize
pub fn next_end_of_word(&self, index: usize) -> usize
Returns the position of the next end of a word from the given grapheme
index.
Sourcepub fn select(&self, start: usize, end: usize) -> Self
pub fn select(&self, start: usize, end: usize) -> Self
Returns a new Value containing the graphemes from start until the
given end.
Sourcepub fn until(&self, index: usize) -> Self
pub fn until(&self, index: usize) -> Self
Returns a new Value containing the graphemes until the given
index.
Sourcepub fn insert(&mut self, index: usize, c: char)
pub fn insert(&mut self, index: usize, c: char)
Inserts a new char at the given grapheme index.
Sourcepub fn insert_many(&mut self, index: usize, value: Value)
pub fn insert_many(&mut self, index: usize, value: Value)
Inserts a bunch of graphemes at the given grapheme index.
Sourcepub fn remove_many(&mut self, start: usize, end: usize)
pub fn remove_many(&mut self, start: usize, end: usize)
Removes the graphemes from start to end.
Sourcepub fn secure(&self) -> Self
pub fn secure(&self) -> Self
Returns a new Value with all its graphemes replaced with the
dot (‘•’) character.
Sourcepub fn byte_index_at_grapheme(&self, grapheme_index: usize) -> usize
pub fn byte_index_at_grapheme(&self, grapheme_index: usize) -> usize
Converts a grapheme index to a byte index in the underlying string.
Sourcepub fn rfind_char(&self, ch: char) -> Option<usize>
pub fn rfind_char(&self, ch: char) -> Option<usize>
Returns the grapheme index of the last occurrence of the given character, searching from the end.
Sourcepub fn grapheme_index_at_byte(&self, byte_index: usize) -> usize
pub fn grapheme_index_at_byte(&self, byte_index: usize) -> usize
Converts a byte index to a grapheme index.